@@ -84,7 +84,7 @@ def is_scalar_record(record):
     return(scalar)
 
 
-def get_data(dset, i_slice=None, pos_slice=None, output_type=np.float64):
+def get_data(dset, i_slice=None, pos_slice=None, output_type=None):
     """
     Extract the data from a (possibly constant) dataset
     Slice the data according to the parameters i_slice and pos_slice
@@ -145,10 +145,11 @@ def get_data(dset, i_slice=None, pos_slice=None, output_type=np.float64):
             data = dset[tuple_index]
 
     # Convert to the right type
-    if data.dtype != output_type:
+    if (output_type is not None) and (data.dtype != output_type):
         data = data.astype( output_type )
     # Scale by the conversion factor
-    if output_type in [ np.float64, np.float32, np.float16 ]:
+    if np.issubdtype(data.dtype, np.floating) or \
+        np.issubdtype(data.dtype, np.complexfloating):
         if dset.attrs['unitSI'] != 1.0:
             data *= dset.attrs['unitSI']
 
